Struct DebugValue

struct DebugValue<T: fmt::Debug>(_)

A Value which serializes as a string using fmt::Debug.

Implementations

impl<T> Any for DebugValue<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DebugValue<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DebugValue<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DebugValue<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Freeze for DebugValue<T>

impl<T> From for DebugValue<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for DebugValue<T>

impl<T> Send for DebugValue<T>

impl<T> Sync for DebugValue<T>

impl<T> ToOwned for DebugValue<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> Unpin for DebugValue<T>

impl<T> UnsafeUnpin for DebugValue<T>

impl<T> UnwindSafe for DebugValue<T>

impl<T> Value for DebugValue<T>

fn record(self: &Self, key: &Field, visitor: &mut dyn Visit)

impl<T, U> Into for DebugValue<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DebugValue<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DebugValue<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::clone::Clone + fmt::Debug> Clone for DebugValue<T>

fn clone(self: &Self) -> DebugValue<T>

impl<T: fmt::Debug> Debug for DebugValue<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result