Struct DisplayValue

struct DisplayValue<T: fmt::Display>(_)

A Value which serializes using fmt::Display.

Uses record_debug in the Value implementation to avoid an unnecessary evaluation.

Implementations

impl<T> Any for DisplayValue<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DisplayValue<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DisplayValue<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DisplayValue<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Freeze for DisplayValue<T>

impl<T> From for DisplayValue<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for DisplayValue<T>

impl<T> Send for DisplayValue<T>

impl<T> Sync for DisplayValue<T>

impl<T> ToOwned for DisplayValue<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DisplayValue<T>

fn to_string(self: &Self) -> String

impl<T> Unpin for DisplayValue<T>

impl<T> UnsafeUnpin for DisplayValue<T>

impl<T> UnwindSafe for DisplayValue<T>

impl<T> Value for DisplayValue<T>

fn record(self: &Self, key: &Field, visitor: &mut dyn Visit)

impl<T, U> Into for DisplayValue<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DisplayValue<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DisplayValue<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::clone::Clone + fmt::Display> Clone for DisplayValue<T>

fn clone(self: &Self) -> DisplayValue<T>

impl<T: fmt::Display> Debug for DisplayValue<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T: fmt::Display> Display for DisplayValue<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result