Struct Field

struct Field { ... }

An opaque key allowing O(1) access to a field in a Span's key-value data.

As keys are defined by the metadata of a span, rather than by an individual instance of a span, a key may be used to access the same field across all instances of a given span with the same metadata. Thus, when a subscriber observes a new span, it need only access a field by name once, and use the key for that name for all other accesses.

Implementations

impl Field

fn callsite(self: &Self) -> Identifier

Returns an Identifier that uniquely identifies the Callsite which defines this field.

fn name(self: &Self) -> &'static str

Returns a string representing the name of the field.

fn index(self: &Self) -> usize

Returns the index of this field in its FieldSet.

impl AsRef for Field

fn as_ref(self: &Self) -> &str

impl Clone for Field

fn clone(self: &Self) -> Self

impl Debug for Field

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Field

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Field

impl Freeze for Field

impl Hash for Field

fn hash<H>(self: &Self, state: &mut H)
where
    H: Hasher

impl PartialEq for Field

fn eq(self: &Self, other: &Self) -> bool

impl RefUnwindSafe for Field

impl Send for Field

impl Sync for Field

impl Unpin for Field

impl UnsafeUnpin for Field

impl UnwindSafe for Field

impl<T> Any for Field

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Field

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Field

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Field

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Field

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Field

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for Field

fn to_string(self: &Self) -> String

impl<T, U> Into for Field

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Field

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Field

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>