Struct Level

struct Level(_)

Describes the level of verbosity of a span or event.

Comparing Levels

Level implements the PartialOrd and Ord traits, allowing two Levels to be compared to determine which is considered more or less verbose. Levels which are more verbose are considered "greater than" levels which are less verbose, with Level::ERROR considered the lowest, and Level::TRACE considered the highest.

For example:

use tracing_core::Level;

assert!(Level::TRACE > Level::DEBUG);
assert!(Level::ERROR < Level::WARN);
assert!(Level::INFO <= Level::DEBUG);
assert_eq!(Level::TRACE, Level::TRACE);

Filtering

Levels are typically used to implement filtering that determines which spans and events are enabled. Depending on the use case, more or less verbose diagnostics may be desired. For example, when running in development, DEBUG-level traces may be enabled by default. When running in production, only INFO-level and lower traces might be enabled. Libraries may include very verbose diagnostics at the DEBUG and/or TRACE levels. Applications using those libraries typically chose to ignore those traces. However, when debugging an issue involving said libraries, it may be useful to temporarily enable the more verbose traces.

The LevelFilter type is provided to enable filtering traces by verbosity. Levels can be compared against LevelFilters, and LevelFilter has a variant for each Level, which compares analogously to that level. In addition, LevelFilter adds a LevelFilter::OFF variant, which is considered "less verbose" than every other Level. This is intended to allow filters to completely disable tracing in a particular context.

For example:

use tracing_core::{Level, LevelFilter};

assert!(LevelFilter::OFF < Level::TRACE);
assert!(LevelFilter::TRACE > Level::DEBUG);
assert!(LevelFilter::ERROR < Level::WARN);
assert!(LevelFilter::INFO <= Level::DEBUG);
assert!(LevelFilter::INFO >= Level::INFO);

Examples

Below is a simple example of how a Subscriber could implement filtering through a LevelFilter. When a span or event is recorded, the Subscriber::enabled method compares the span or event's Level against the configured LevelFilter. The optional Subscriber::max_level_hint method can also be implemented to allow spans and events above a maximum verbosity level to be skipped more efficiently, often improving performance in short-lived programs.

use tracing_core::{span, Event, Level, LevelFilter, Subscriber, Metadata};
# use tracing_core::span::{Id, Record, Current};

#[derive(Debug)]
pub struct MySubscriber {
    /// The most verbose level that this subscriber will enable.
    max_level: LevelFilter,

    // ...
}

impl MySubscriber {
    /// Returns a new `MySubscriber` which will record spans and events up to
    /// `max_level`.
    pub fn with_max_level(max_level: LevelFilter) -> Self {
        Self {
            max_level,
            // ...
        }
    }
}
impl Subscriber for MySubscriber {
    fn enabled(&self, meta: &Metadata<'_>) -> bool {
        // A span or event is enabled if it is at or below the configured
        // maximum level.
        meta.level() <= &self.max_level
    }

    // This optional method returns the most verbose level that this
    // subscriber will enable. Although implementing this method is not
    // *required*, it permits additional optimizations when it is provided,
    // allowing spans and events above the max level to be skipped
    // more efficiently.
    fn max_level_hint(&self) -> Option<LevelFilter> {
        Some(self.max_level)
    }

    // Implement the rest of the subscriber...
    fn new_span(&self, span: &span::Attributes<'_>) -> span::Id {
        // ...
        # drop(span); Id::from_u64(1)
    }

    fn event(&self, event: &Event<'_>) {
        // ...
        # drop(event);
    }

    // ...
    # fn enter(&self, _: &Id) {}
    # fn exit(&self, _: &Id) {}
    # fn record(&self, _: &Id, _: &Record<'_>) {}
    # fn record_follows_from(&self, _: &Id, _: &Id) {}
}

It is worth noting that the tracing-subscriber crate provides additional APIs for performing more sophisticated filtering, such as enabling different levels based on which module or crate a span or event is recorded in.

Implementations

impl Level

fn as_str(self: &Self) -> &'static str

Returns the string representation of the Level.

This returns the same string as the fmt::Display implementation.

impl Clone for Level

fn clone(self: &Self) -> Level

impl Copy for Level

impl Debug for Level

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Level

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Level

impl Freeze for Level

impl FromStr for Level

fn from_str(s: &str) -> Result<Self, ParseLevelError>

impl Hash for Level

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for Level

fn cmp(self: &Self, other: &Self) -> Ordering

impl PartialEq for Level

fn eq(self: &Self, other: &Level) -> bool

impl PartialEq for Level

fn eq(self: &Self, other: &LevelFilter) -> bool

impl PartialOrd for Level

fn partial_cmp(self: &Self, other: &Level) -> Option<Ordering>
fn lt(self: &Self, other: &Level) -> bool
fn le(self: &Self, other: &Level) -> bool
fn gt(self: &Self, other: &Level) -> bool
fn ge(self: &Self, other: &Level) -> bool

impl PartialOrd for Level

fn partial_cmp(self: &Self, other: &LevelFilter) -> Option<Ordering>
fn lt(self: &Self, other: &LevelFilter) -> bool
fn le(self: &Self, other: &LevelFilter) -> bool
fn gt(self: &Self, other: &LevelFilter) -> bool
fn ge(self: &Self, other: &LevelFilter) -> bool

impl RefUnwindSafe for Level

impl Send for Level

impl StructuralPartialEq for Level

impl Sync for Level

impl Unpin for Level

impl UnsafeUnpin for Level

impl UnwindSafe for Level

impl<T> Any for Level

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Level

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Level

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Level

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Level

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Level

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for Level

fn to_string(self: &Self) -> String

impl<T, U> Into for Level

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Level

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Level

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>