Struct Record

struct Record<'a> { ... }

A set of fields recorded by a span.

Implementations

impl<'a> Record<'a>

fn new(values: &'a ValueSet<'a>) -> Self

Constructs a new Record from a ValueSet.

fn record(self: &Self, visitor: &mut dyn Visit)

Records all the fields in this Record with the provided Visitor.

fn len(self: &Self) -> usize

Returns the number of fields that would be visited from this Record when Record::record() is called

fn contains(self: &Self, field: &Field) -> bool

Returns true if this Record contains a value for the given Field.

fn is_empty(self: &Self) -> bool

Returns true if this Record contains no values.

impl<'a> Debug for Record<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Freeze for Record<'a>

impl<'a> RefUnwindSafe for Record<'a>

impl<'a> Send for Record<'a>

impl<'a> Sync for Record<'a>

impl<'a> Unpin for Record<'a>

impl<'a> UnsafeUnpin for Record<'a>

impl<'a> UnwindSafe for Record<'a>

impl<T> Any for Record<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Record<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Record<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Record<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Record<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Record<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Record<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>