Struct DefaultCallsite
struct DefaultCallsite { ... }
A default Callsite implementation.
Implementations
impl DefaultCallsite
const fn new(meta: &'static Metadata<'static>) -> SelfReturns a new
DefaultCallsitewith the specifiedMetadata.fn register(self: &'static Self) -> InterestRegisters this callsite with the global callsite registry.
If the callsite is already registered, this does nothing. When using
DefaultCallsite, this method should be preferred overtracing_core::callsite::register, as it ensures that the callsite is only registered a single time.Other callsite implementations will generally ensure that callsites are not re-registered through another mechanism.
See the documentation on callsite registration for details on the global callsite registry.
fn interest(self: &'static Self) -> InterestReturns the callsite's cached
Interest, or registers it for the first time if it has not yet been registered.
impl Callsite for DefaultCallsite
fn set_interest(self: &Self, interest: Interest)fn metadata(self: &Self) -> &Metadata<'static>
impl Debug for DefaultCallsite
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for DefaultCallsite
impl RefUnwindSafe for DefaultCallsite
impl Send for DefaultCallsite
impl Sync for DefaultCallsite
impl Unpin for DefaultCallsite
impl UnsafeUnpin for DefaultCallsite
impl UnwindSafe for DefaultCallsite
impl<T> Any for DefaultCallsite
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DefaultCallsite
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DefaultCallsite
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for DefaultCallsite
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for DefaultCallsite
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DefaultCallsite
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DefaultCallsite
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>