Struct Identifier
struct Identifier(_)
Uniquely identifies a Callsite
Two Identifiers are equal if they both refer to the same callsite.
Implementations
impl Clone for Identifier
fn clone(self: &Self) -> Identifier
impl Debug for Identifier
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Identifier
impl Freeze for Identifier
impl Hash for Identifier
fn hash<H>(self: &Self, state: &mut H) where H: Hasher
impl PartialEq for Identifier
fn eq(self: &Self, other: &Identifier) -> bool
impl RefUnwindSafe for Identifier
impl Send for Identifier
impl Sync for Identifier
impl Unpin for Identifier
impl UnsafeUnpin for Identifier
impl UnwindSafe for Identifier
impl<T> Any for Identifier
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Identifier
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Identifier
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Identifier
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Identifier
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Identifier
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Identifier
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Identifier
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Identifier
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>