Trait Callsite
trait Callsite: Sync
Trait implemented by callsites.
These functions are only intended to be called by the callsite registry, which correctly handles determining the common interest between all subscribers.
See the module-level documentation for details on callsites.
Required Methods
fn set_interest(self: &Self, interest: Interest)Sets the
Interestfor this callsite.See the documentation on callsite interest caching for details.
fn metadata(self: &Self) -> &Metadata<'_>Returns the metadata associated with the callsite.
Note: Implementations of this method should not produce
Metadatathat share the same callsiteIdentifierbut otherwise differ in any way (e.g., have differentnames).
Implementors
impl Callsite for DefaultCallsite