Function with_default
fn with_default<T, impl FnOnce() -> T: FnOnce() -> T>(dispatcher: &Dispatch, f: impl FnOnce() -> T) -> T
Sets this dispatch as the default for the duration of a closure.
The default dispatcher is used when creating a new span or
Event.
Note: This function required the Rust standard library.
no_std users should use
set_global_default instead.