Struct Empty
struct Empty
An empty field.
This can be used to indicate that the value of a field is not currently present but will be recorded later.
When a field's value is Empty. it will not be recorded.
Implementations
impl Debug for Empty
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Empty
impl Freeze for Empty
impl PartialEq for Empty
fn eq(self: &Self, other: &Empty) -> bool
impl RefUnwindSafe for Empty
impl Send for Empty
impl StructuralPartialEq for Empty
impl Sync for Empty
impl Unpin for Empty
impl UnsafeUnpin for Empty
impl UnwindSafe for Empty
impl Value for Empty
fn record(self: &Self, _: &Field, _: &mut dyn Visit)
impl<T> Any for Empty
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Empty
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Empty
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Empty
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Empty
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Empty
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Empty
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>