Struct ValueSet
struct ValueSet<'a> { ... }
A set of fields and values for a span.
Implementations
impl ValueSet<'_>
fn callsite(self: &Self) -> IdentifierReturns an
Identifierthat uniquely identifies theCallsitedefining the fields thisValueSetrefers to.fn record(self: &Self, visitor: &mut dyn Visit)Visits all the fields in this
ValueSetwith the provided visitor.fn len(self: &Self) -> usizeReturns the number of fields in this
ValueSetthat would be visited by a given visitor to theValueSet::record()method.fn is_empty(self: &Self) -> boolReturns true if this
ValueSetcontains no values.
impl Debug for ValueSet<'_>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ValueSet<'_>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for ValueSet<'a>
impl<'a> RefUnwindSafe for ValueSet<'a>
impl<'a> Send for ValueSet<'a>
impl<'a> Sync for ValueSet<'a>
impl<'a> Unpin for ValueSet<'a>
impl<'a> UnsafeUnpin for ValueSet<'a>
impl<'a> UnwindSafe for ValueSet<'a>
impl<T> Any for ValueSet<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ValueSet<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ValueSet<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ValueSet<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for ValueSet<'a>
fn to_string(self: &Self) -> String
impl<T, U> Into for ValueSet<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ValueSet<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ValueSet<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>