Trait Value

trait Value: crate::sealed::Sealed

A field value of an erased type.

Implementors of Value may call the appropriate typed recording methods on the visitor passed to their record method in order to indicate how their data should be recorded.

Required Methods

fn record(self: &Self, key: &Field, visitor: &mut dyn Visit)

Visits this value with the given Visitor.

Implementors