Struct Kind

struct Kind(_)

Indicates whether the callsite is a span or event.

Implementations

impl Kind

fn is_span(self: &Self) -> bool

Return true if the callsite kind is Span

fn is_event(self: &Self) -> bool

Return true if the callsite kind is Event

fn is_hint(self: &Self) -> bool

Return true if the callsite kind is Hint

const fn hint(self: Self) -> Self

Sets that this Kind is a hint.

This can be called on SPAN and EVENT kinds to construct a hint callsite that also counts as a span or event.

impl Clone for Kind

fn clone(self: &Self) -> Kind

impl Debug for Kind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Kind

impl Freeze for Kind

impl PartialEq for Kind

fn eq(self: &Self, other: &Kind) -> bool

impl RefUnwindSafe for Kind

impl Send for Kind

impl StructuralPartialEq for Kind

impl Sync for Kind

impl Unpin for Kind

impl UnsafeUnpin for Kind

impl UnwindSafe for Kind

impl<T> Any for Kind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Kind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Kind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Kind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Kind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Kind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Kind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Kind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Kind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>