Struct Attributes

struct Attributes<'a> { ... }

Attributes provided to a Subscriber describing a new span when it is created.

Implementations

impl<'a> Attributes<'a>

fn new(metadata: &'static Metadata<'static>, values: &'a ValueSet<'a>) -> Self

Returns Attributes describing a new child span of the current span, with the provided metadata and values.

fn new_root(metadata: &'static Metadata<'static>, values: &'a ValueSet<'a>) -> Self

Returns Attributes describing a new span at the root of its own trace tree, with the provided metadata and values.

fn child_of(parent: Id, metadata: &'static Metadata<'static>, values: &'a ValueSet<'a>) -> Self

Returns Attributes describing a new child span of the specified parent span, with the provided metadata and values.

fn metadata(self: &Self) -> &'static Metadata<'static>

Returns a reference to the new span's metadata.

fn values(self: &Self) -> &ValueSet<'a>

Returns a reference to a ValueSet containing any values the new span was created with.

fn is_root(self: &Self) -> bool

Returns true if the new span should be a root.

fn is_contextual(self: &Self) -> bool

Returns true if the new span's parent should be determined based on the current context.

If this is true and the current thread is currently inside a span, then that span should be the new span's parent. Otherwise, if the current thread is not inside a span, then the new span will be the root of its own trace tree.

fn parent(self: &Self) -> Option<&Id>

Returns the new span's explicitly-specified parent, if there is one.

Otherwise (if the new span is a root or is a child of the current span), returns None.

fn record(self: &Self, visitor: &mut dyn Visit)

Records all the fields in this set of Attributes with the provided Visitor.

fn contains(self: &Self, field: &Field) -> bool

Returns true if this set of Attributes contains a value for the given Field.

fn is_empty(self: &Self) -> bool

Returns true if this set of Attributes contains no values.

fn fields(self: &Self) -> &FieldSet

Returns the set of all fields defined by this span's Metadata.

Note that the FieldSet returned by this method includes all the fields declared by this span, not just those with values that are recorded as part of this set of Attributes. Other fields with values not present in this Attributes' value set may record values later.

impl<'a> Debug for Attributes<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Freeze for Attributes<'a>

impl<'a> RefUnwindSafe for Attributes<'a>

impl<'a> Send for Attributes<'a>

impl<'a> Sync for Attributes<'a>

impl<'a> Unpin for Attributes<'a>

impl<'a> UnsafeUnpin for Attributes<'a>

impl<'a> UnwindSafe for Attributes<'a>

impl<T> Any for Attributes<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Attributes<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Attributes<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Attributes<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Attributes<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Attributes<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Attributes<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>