Struct Record
struct Record<'a> { ... }
A set of fields recorded by a span.
Implementations
impl<'a> Record<'a>
fn new(values: &'a ValueSet<'a>) -> SelfConstructs a new
Recordfrom aValueSet.fn record(self: &Self, visitor: &mut dyn Visit)Records all the fields in this
Recordwith the provided Visitor.fn len(self: &Self) -> usizeReturns the number of fields that would be visited from this
RecordwhenRecord::record()is calledfn contains(self: &Self, field: &Field) -> boolReturns
trueif thisRecordcontains a value for the givenField.fn is_empty(self: &Self) -> boolReturns true if this
Recordcontains no values.
impl<'a> Debug for Record<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for Record<'a>
impl<'a> RefUnwindSafe for Record<'a>
impl<'a> Send for Record<'a>
impl<'a> Sync for Record<'a>
impl<'a> Unpin for Record<'a>
impl<'a> UnsafeUnpin for Record<'a>
impl<'a> UnwindSafe for Record<'a>
impl<T> Any for Record<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Record<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Record<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Record<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Record<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Record<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Record<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>