Struct Interest
struct Interest(_)
Indicates a Subscriber's interest in a particular callsite.
Subscribers return an Interest from their register_callsite methods
in order to determine whether that span should be enabled or disabled.
Implementations
impl Interest
fn never() -> SelfReturns an
Interestindicating that the subscriber is never interested in being notified about a callsite.If all active subscribers are
never()interested in a callsite, it will be completely disabled unless a new subscriber becomes active.fn sometimes() -> SelfReturns an
Interestindicating the subscriber is sometimes interested in being notified about a callsite.If all active subscribers are
sometimesorneverinterested in a callsite, the currently active subscriber will be asked to filter that callsite every time it creates a span. This will be the case until a new subscriber expresses that it isalwaysinterested in the callsite.fn always() -> SelfReturns an
Interestindicating the subscriber is always interested in being notified about a callsite.If any subscriber expresses that it is
always()interested in a given callsite, then the callsite will always be enabled.fn is_never(self: &Self) -> boolReturns
trueif the subscriber is never interested in being notified about this callsite.fn is_sometimes(self: &Self) -> boolReturns
trueif the subscriber is sometimes interested in being notified about this callsite.fn is_always(self: &Self) -> boolReturns
trueif the subscriber is always interested in being notified about this callsite.
impl Clone for Interest
fn clone(self: &Self) -> Interest
impl Debug for Interest
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Interest
impl RefUnwindSafe for Interest
impl Send for Interest
impl Sync for Interest
impl Unpin for Interest
impl UnsafeUnpin for Interest
impl UnwindSafe for Interest
impl<T> Any for Interest
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Interest
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Interest
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Interest
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Interest
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Interest
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Interest
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Interest
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Interest
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>